@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.5021";
+our $VERSION = "1.6000";
 
 =head1 NAME
 
@@ -116,8 +116,8 @@ writing code.
 
 It queries the CPAN Meta DB site at L<http://cpanmetadb.plackperl.org/>.
 The site is updated at least every hour to reflect the latest changes
-from fast syncing mirrors. The script then also falls back
-to scrape the site L<http://search.cpan.org/>.
+from fast syncing mirrors. The script then also falls back to query the
+module at L<http://metacpan.org/> using its wonderful API.
 
 Fetched files are unpacked in C<~/.cpanm> and automatically cleaned up
 periodically.  You can configure the location of this with the
@@ -228,15 +228,11 @@ The standalone executable contains the following modules embedded.
 
 =item L<JSON::PP> Copyright 2007−2011 by Makamaka Hannyaharamitu
 
-=item L<CPAN::Meta> Copyright (c) 2010 by David Golden and Ricardo Signes
+=item L<CPAN::Meta::Requirements> Copyright (c) 2010 by David Golden and Ricardo Signes
 
-=item L<Try::Tiny> Copyright (c) 2009 Yuval Kogman
+=item L<CPAN::Meta::YAML> Copyright 2010 Adam Kennedy
 
-=item L<parent> Copyright (c) 2007-10 Max Maischein
-
-=item L<Version::Requirements> copyright (c) 2010 by Ricardo Signes
-
-=item L<CPAN::Meta::YAML> copyright (c) 2010 by Adam Kennedy
+=item L<File::pushd> Copyright 2012 David Golden
 
 =back
 
